Going deeper into Manen
=======================

.. automodule:: manen


API Documentation
-----------------

Explore directly the code to discover all features proposed by :py:mod:`manen`.

.. toctree::
   :maxdepth: 2
   :titlesonly:

   ./manen.browser.rst
   ./manen.exceptions.rst
   ./manen.finder.rst
   ./manen.helpers.rst
   ./manen.page_object_model.rst
